==> haskell-hslua-repl-0.1.2-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-FFYfKIqefap8PMfdAcoGjr
key:                  hslua-repl-0.1.2-FFYfKIqefap8PMfdAcoGjr
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  3ddd5ccffe558a0bd7e6d82bdd365c31
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-FFYfKIqefap8PMfdAcoGjr
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    hslua-core-2.3.1-1AmI8zGzjZL1RLIxXelUsx
    isocline-1.0.9-2dBQZhT1SqR1bCMBoLzGES
    lua-2.3.2-CW5U8pmQtcGIvTgmqAkLf9 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-repl-0.1.2-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-repl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-repl
version:              0.1.2
visibility:           public
id:                   hslua-repl-0.1.2-5xmj96sHu1sLBUWxtrptKO
key:                  hslua-repl-0.1.2-5xmj96sHu1sLBUWxtrptKO
license:              MIT
copyright:            © 2023-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Isocline-based Lua REPL
description:          An embeddable Lua REPL built with Isocline and HsLua.
category:             Foreign
abi:                  025a0c90f5691ef5ec6d0b84d52c179e
exposed:              True
exposed-modules:      HsLua.REPL
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hslua-repl-0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hslua-repl-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-repl
hs-libraries:         HShslua-repl-0.1.2-5xmj96sHu1sLBUWxtrptKO
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    hslua-core-2.3.1-D3NnxZFUi8xELEn2vlm0HZ
    isocline-1.0.9-2dBQZhT1SqR1bCMBoLzGES
    lua-2.3.2-87qENezBZxGIO33FCOMzTp text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hslua-repl/html/hslua-repl.haddock
haddock-html:         /usr/share/doc/haskell-hslua-repl/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
